[glom] Replace deprecated Gtk::HBox and Gtk:VBox with Gtk::Box.



commit 24f15cdf9342a6e8551debf0d67bddf20080ca4c
Author: Murray Cumming <murrayc murrayc com>
Date:   Thu Sep 1 16:30:19 2011 +0200

    Replace deprecated Gtk::HBox and Gtk:VBox with Gtk::Box.
    
    * glom/*.[h|cc]: HBox and VBox are deprecated.
    However, these are still used in the .glade files.

 ChangeLog                                          |    7 +++++
 glom/application.h                                 |    2 +-
 glom/bakery/app_withdoc_gtk.cc                     |    8 ++++--
 glom/bakery/app_withdoc_gtk.h                      |    4 +-
 glom/box_withbuttons.cc                            |   11 +++++----
 glom/box_withbuttons.h                             |    6 ++--
 glom/filechooser_export.cc                         |    2 +-
 glom/filechooser_export.h                          |    2 +-
 glom/frame_glom.cc                                 |    6 ++--
 glom/frame_glom.h                                  |    4 +-
 glom/libglom/test_avahi_publisher.cc               |    4 +-
 glom/mode_data/box_data_details.cc                 |    2 +-
 glom/mode_data/box_data_details.h                  |    2 +-
 .../mode_data/datawidget/combo_as_radio_buttons.cc |    5 ++-
 glom/mode_data/datawidget/combo_as_radio_buttons.h |    2 +-
 glom/mode_data/datawidget/datawidget.cc            |    4 +-
 glom/mode_data/datawidget/dialog_choose_id.h       |    2 +-
 glom/mode_data/db_adddel/db_adddel.cc              |    3 +-
 glom/mode_data/db_adddel/db_adddel.h               |    4 +-
 glom/mode_data/db_adddel/db_adddel_withbuttons.cc  |    2 +-
 glom/mode_data/flowtablewithfields.cc              |    4 +-
 glom/mode_data/test_flowtablewithfields.cc         |    2 +-
 glom/mode_design/fields/dialog_fielddefinition.h   |    6 ++--
 .../layout/layout_item_dialogs/box_formatting.cc   |    2 +-
 .../layout/layout_item_dialogs/box_formatting.h    |   14 +++++-----
 .../layout_item_dialogs/dialog_field_layout.h      |    2 +-
 .../layout_item_dialogs/dialog_imageobject.h       |    2 +-
 .../layout/layout_item_dialogs/dialog_textobject.h |    2 +-
 .../print_layouts/dialog_text_formatting.h         |    2 +-
 .../print_layouts/window_print_layout_edit.h       |    6 ++--
 .../dialog_relationships_overview.cc               |    2 +-
 glom/mode_find/box_data_list_find.cc               |    2 +-
 glom/mode_find/box_data_list_find.h                |    2 +-
 glom/utility_widgets/adddel/adddel.cc              |    5 ++-
 glom/utility_widgets/adddel/adddel.h               |    4 +-
 .../eggspreadtablemm/test_spreadtablednd.cc        |   14 +++++-----
 .../filechooserdialog_saveextras.cc                |   16 ++++++++-----
 .../utility_widgets/filechooserdialog_saveextras.h |    2 +-
 glom/utility_widgets/flowtable.cc                  |   24 ++++++++++----------
 glom/utility_widgets/flowtable.h                   |    8 +++---
 glom/utility_widgets/placeholder.cc                |    7 +++--
 glom/utility_widgets/placeholder.h                 |    2 +-
 glom/utility_widgets/test_flowtable.cc             |    2 +-
 glom/utility_widgets/test_flowtable_dnd.cc         |    2 +-
 44 files changed, 117 insertions(+), 99 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 974c593..d615e0b 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,12 @@
 2011-09-01  Murray Cumming  <murrayc murrayc com>
 
+	Replace deprecated Gtk::HBox and Gtk:VBox with Gtk::Box.
+
+	* glom/*.[h|cc]: HBox and VBox are deprecated.
+	However, these are still used in the .glade files.
+
+2011-09-01  Murray Cumming  <murrayc murrayc com>
+
 	Update EggSpreadTableDnd from libegg. 
 
 	* glom/utility_widgets/eggspreadtable/eggspreadtablednd.[h|c]:
diff --git a/glom/application.h b/glom/application.h
index 3b347c0..e681cbe 100644
--- a/glom/application.h
+++ b/glom/application.h
@@ -253,7 +253,7 @@ private:
   Glib::RefPtr<Gtk::ToggleAction> m_toggleaction_network_shared;
   sigc::connection m_connection_toggleaction_network_shared;
 
-  Gtk::VBox* m_pBoxTop;
+  Gtk::Box* m_pBoxTop;
   Frame_Glom* m_pFrame;
   
   bool m_bAboutShown;
diff --git a/glom/bakery/app_withdoc_gtk.cc b/glom/bakery/app_withdoc_gtk.cc
index 793a31d..9e74909 100644
--- a/glom/bakery/app_withdoc_gtk.cc
+++ b/glom/bakery/app_withdoc_gtk.cc
@@ -46,7 +46,8 @@ namespace GlomBakery
 
 App_WithDoc_Gtk::App_WithDoc_Gtk(const Glib::ustring& appname)
 : App_WithDoc(appname),
-  m_pVBox(0)
+  m_pVBox(0),
+  m_VBox_PlaceHolder(Gtk::ORIENTATION_VERTICAL)
 {
   init_app_name(appname);
 }
@@ -55,7 +56,8 @@ App_WithDoc_Gtk::App_WithDoc_Gtk(const Glib::ustring& appname)
 App_WithDoc_Gtk::App_WithDoc_Gtk(BaseObjectType* cobject, const Glib::ustring& appname)
 : App_WithDoc(appname),
   ParentWindow(cobject), 
-  m_pVBox(0)
+  m_pVBox(0),
+  m_VBox_PlaceHolder(Gtk::ORIENTATION_VERTICAL)
 {
   init_app_name(appname);
 
@@ -98,7 +100,7 @@ void App_WithDoc_Gtk::init_layout()
   //If not, then we create a default one and add it to the window.
   if(!m_pVBox)
   {
-    m_pVBox = new Gtk::VBox();
+    m_pVBox = new Gtk::VBox(Gtk::ORIENTATION_VERTICAL);
     Gtk::Window::add(*m_pVBox);
   }
 
diff --git a/glom/bakery/app_withdoc_gtk.h b/glom/bakery/app_withdoc_gtk.h
index 573ce29..b4c8c1c 100644
--- a/glom/bakery/app_withdoc_gtk.h
+++ b/glom/bakery/app_withdoc_gtk.h
@@ -124,8 +124,8 @@ protected:
   Glib::RefPtr<Gtk::ActionGroup> m_refEditActionGroup;
 
   //Member widgets:
-  Gtk::VBox* m_pVBox;
-  Gtk::VBox m_VBox_PlaceHolder;
+  Gtk::Box* m_pVBox;
+  Gtk::Box m_VBox_PlaceHolder;
 
   //Menu stuff:
   Glib::RefPtr<Gtk::Action> m_action_save, m_action_saveas;
diff --git a/glom/box_withbuttons.cc b/glom/box_withbuttons.cc
index 1dd8a24..df2764d 100644
--- a/glom/box_withbuttons.cc
+++ b/glom/box_withbuttons.cc
@@ -30,7 +30,8 @@ namespace Glom
 {
 
 Box_WithButtons::Box_WithButtons()
-: m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
@@ -43,8 +44,8 @@ Box_WithButtons::Box_WithButtons()
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
@@ -57,8 +58,8 @@ Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
 }
diff --git a/glom/box_withbuttons.h b/glom/box_withbuttons.h
index f15af87..e93f1a0 100644
--- a/glom/box_withbuttons.h
+++ b/glom/box_withbuttons.h
@@ -33,12 +33,12 @@
 namespace Glom
 {
 
-/** A Gtk::VBox base widget class, 
+/** A Gtk::Box base widget class, 
  * with some extra signals to allow derived classes to be used generically in 
  * Window_BoxHolder, allowing the dialog to respond to buttons in the box.
  */
 class Box_WithButtons :
-  public Gtk::VBox
+  public Gtk::Box
 {
 public: 
   Box_WithButtons();
@@ -74,7 +74,7 @@ private:
   //Member data:
   //Glib::ustring m_strHint; //Help text.
 
-  Gtk::HBox m_Box_Buttons;
+  Gtk::Box m_Box_Buttons;
   Gtk::Button m_Button_Cancel; //Derived classes can use it if it's necessary.
 };
 
diff --git a/glom/filechooser_export.cc b/glom/filechooser_export.cc
index cb2b77e..0e37873 100644
--- a/glom/filechooser_export.cc
+++ b/glom/filechooser_export.cc
@@ -30,7 +30,7 @@ namespace Glom
 
 FileChooser_Export::FileChooser_Export()
 : Gtk::FileChooserDialog(_("Export to File"), Gtk::FILE_CHOOSER_ACTION_SAVE),
-  m_extra_widget(false, Utils::DEFAULT_SPACING_SMALL),
+  m_extra_widget(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_button_format(_("Define Data _Format"), true /* use mnenomic */),
   m_pDialogLayout(0),
diff --git a/glom/filechooser_export.h b/glom/filechooser_export.h
index 17deef3..b405fa7 100644
--- a/glom/filechooser_export.h
+++ b/glom/filechooser_export.h
@@ -48,7 +48,7 @@ private:
 #endif
 
   //Member widgets:
-  Gtk::HBox m_extra_widget;
+  Gtk::Box m_extra_widget;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Gtk::Button m_button_format;
diff --git a/glom/frame_glom.cc b/glom/frame_glom.cc
index 68319a9..7615fcc 100644
--- a/glom/frame_glom.cc
+++ b/glom/frame_glom.cc
@@ -80,7 +80,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 : PlaceHolder(cobject, builder),
   m_pLabel_Table_DataMode(0),
   m_pLabel_Table_FindMode(0),
-  m_Box_RecordsCount(false, Utils::DEFAULT_SPACING_SMALL),
+  m_Box_RecordsCount(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_FindAll(_("Find All")),
   m_pBox_Mode(0),
 #ifndef GLOM_ENABLE_MAEMO
@@ -123,7 +123,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
 
   //QuickFind widgets:
   //We don't use Glade for these, so it easier to modify them for the Maemo port.
-  m_pBox_QuickFind = Gtk::manage(new Gtk::HBox(false, Utils::DEFAULT_SPACING_SMALL));
+  m_pBox_QuickFind = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL));
   Gtk::Label* label = Gtk::manage(new Gtk::Label(_("Quick _search:"), true));
   m_pBox_QuickFind->pack_start(*label, Gtk::PACK_SHRINK);
 
@@ -192,7 +192,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   #ifdef GLOM_ENABLE_MAEMO
   m_maemo_window_find.set_title(_("Glom: Find"));
 
-  Gtk::VBox* vbox = Gtk::manage(new Gtk::VBox(false, Utils::DEFAULT_SPACING_SMALL));
+  Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, Utils::DEFAULT_SPACING_SMALL));
   vbox->pack_start(*m_pBox_QuickFind, Gtk::PACK_SHRINK);
   vbox->pack_start(m_Notebook_Find, Gtk::PACK_EXPAND_WIDGET);
   m_maemo_window_find.add(*vbox);
diff --git a/glom/frame_glom.h b/glom/frame_glom.h
index d593d12..04cfe70 100644
--- a/glom/frame_glom.h
+++ b/glom/frame_glom.h
@@ -258,7 +258,7 @@ private:
   Gtk::Label* m_pLabel_Table_DataMode;
   Gtk::Label* m_pLabel_Table_FindMode;
 
-  Gtk::HBox m_Box_RecordsCount; //Only show this when in Data mode.
+  Gtk::Box m_Box_RecordsCount; //Only show this when in Data mode.
   Gtk::Label m_Label_RecordsCount;
   Gtk::Label m_Label_FoundCount;
   Gtk::Button m_Button_FindAll;
@@ -273,7 +273,7 @@ private:
 
   Notebook_Data m_Notebook_Data;
 
-  Gtk::HBox* m_pBox_QuickFind; //Only show this when in Find mode.
+  Gtk::Box* m_pBox_QuickFind; //Only show this when in Find mode.
   Gtk::Entry* m_pEntry_QuickFind;
   Gtk::Button* m_pButton_QuickFind;
   Notebook_Find m_Notebook_Find;
diff --git a/glom/libglom/test_avahi_publisher.cc b/glom/libglom/test_avahi_publisher.cc
index 20cd500..4ae5276 100644
--- a/glom/libglom/test_avahi_publisher.cc
+++ b/glom/libglom/test_avahi_publisher.cc
@@ -16,7 +16,7 @@ private:
   virtual void on_button_stop();
 
   //Member widgets:
-  Gtk::VBox m_box;
+  Gtk::Box m_box;
   Gtk::Button m_button_start;
   Gtk::Button m_button_stop;
 
@@ -26,7 +26,7 @@ private:
 
 
 TestWindow::TestWindow()
-: m_box(false, Glom::Utils::DEFAULT_SPACING_SMALL),
+: m_box(Gtk::ORIENTATION_VERTICAL, Glom::Utils::DEFAULT_SPACING_SMALL),
   m_button_start("Start"),
   m_button_stop("Stop"),
   m_avahi_publisher(0)
diff --git a/glom/mode_data/box_data_details.cc b/glom/mode_data/box_data_details.cc
index 526621c..3da2e73 100644
--- a/glom/mode_data/box_data_details.cc
+++ b/glom/mode_data/box_data_details.cc
@@ -38,7 +38,7 @@ namespace Glom
 {
 
 Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
-: m_hbox_content(false, Utils::DEFAULT_SPACING_SMALL),
+: m_hbox_content(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
 #ifndef GLOM_ENABLE_MAEMO
   m_hbox_buttons(Gtk::ORIENTATION_HORIZONTAL),
   m_Button_New(Gtk::Stock::ADD),
diff --git a/glom/mode_data/box_data_details.h b/glom/mode_data/box_data_details.h
index 22beca2..35e9621 100644
--- a/glom/mode_data/box_data_details.h
+++ b/glom/mode_data/box_data_details.h
@@ -142,7 +142,7 @@ protected:
 
   //Member widgets:
   Gtk::ScrolledWindow m_ScrolledWindow;
-  Gtk::HBox m_hbox_content;
+  Gtk::Box m_hbox_content;
   FlowTableWithFields m_FlowTable;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
diff --git a/glom/mode_data/datawidget/combo_as_radio_buttons.cc b/glom/mode_data/datawidget/combo_as_radio_buttons.cc
index 931a280..c1d379c 100644
--- a/glom/mode_data/datawidget/combo_as_radio_buttons.cc
+++ b/glom/mode_data/datawidget/combo_as_radio_buttons.cc
@@ -36,7 +36,8 @@ namespace DataWidgetChildren
 {
 
 ComboAsRadioButtons::ComboAsRadioButtons()
-: ComboChoices()
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  ComboChoices()
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_menu();
@@ -297,7 +298,7 @@ bool ComboAsRadioButtons::on_button_press_event(GdkEventButton *event)
 {
   show_context_menu(event);
 
-  return Gtk::VBox::on_button_press_event(event);
+  return Gtk::Box::on_button_press_event(event);
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
diff --git a/glom/mode_data/datawidget/combo_as_radio_buttons.h b/glom/mode_data/datawidget/combo_as_radio_buttons.h
index 23e8e17..76a85ba 100644
--- a/glom/mode_data/datawidget/combo_as_radio_buttons.h
+++ b/glom/mode_data/datawidget/combo_as_radio_buttons.h
@@ -38,7 +38,7 @@ namespace DataWidgetChildren
  */
 class ComboAsRadioButtons
 :
-  public Gtk::VBox,
+  public Gtk::Box,
   public ComboChoices
 {
 public:
diff --git a/glom/mode_data/datawidget/datawidget.cc b/glom/mode_data/datawidget/datawidget.cc
index 7bdb111..c3e9cf5 100644
--- a/glom/mode_data/datawidget/datawidget.cc
+++ b/glom/mode_data/datawidget/datawidget.cc
@@ -197,12 +197,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     //std::cout <<   "DEBUG: field->get_has_relationship_name()=" << field->get_has_relationship_name() << ", field_info->get_primary_key()=" <<  field_info->get_primary_key() << ", field_is_related_primary_key=" << field_is_related_primary_key << std::endl;
 
 
-    Gtk::HBox* hbox_parent = 0; //Only used if there are extra widgets.
+    Gtk::Box* hbox_parent = 0; //Only used if there are extra widgets.
 
     const bool with_extra_widgets = field_used_in_relationship_to_one || field_is_related_primary_key || (glom_type == Field::TYPE_DATE);
     if(with_extra_widgets)
     {
-      hbox_parent = Gtk::manage( new Gtk::HBox() ); //We put the child (and any extra stuff) in this:
+      hbox_parent = Gtk::manage( new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL) ); //We put the child (and any extra stuff) in this:
       hbox_parent->set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
       hbox_parent->pack_start(*m_child);
diff --git a/glom/mode_data/datawidget/dialog_choose_id.h b/glom/mode_data/datawidget/dialog_choose_id.h
index bfc4e2c..4a9451d 100644
--- a/glom/mode_data/datawidget/dialog_choose_id.h
+++ b/glom/mode_data/datawidget/dialog_choose_id.h
@@ -66,7 +66,7 @@ private:
   void on_box_select_selected(const Gnome::Gda::Value& primary_key);
 
   Gtk::Label* m_label_table_name;
-  Gtk::HBox* m_pBox_QuickFind; //Only show this when in Find mode.
+  Gtk::Box* m_pBox_QuickFind; //Only show this when in Find mode.
   Gtk::Entry* m_pEntry_QuickFind;
   Gtk::Button* m_pButton_QuickFind;
   Gtk::Alignment* m_alignment_parent;
diff --git a/glom/mode_data/db_adddel/db_adddel.cc b/glom/mode_data/db_adddel/db_adddel.cc
index c0d12cc..f3faab7 100644
--- a/glom/mode_data/db_adddel/db_adddel.cc
+++ b/glom/mode_data/db_adddel/db_adddel.cc
@@ -44,7 +44,8 @@ namespace Glom
 {
 
 DbAddDel::DbAddDel()
-: m_column_is_sorted(false),
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_column_is_sorted(false),
   m_column_sorted_direction(false),
   m_column_sorted(0),
 #ifndef GLOM_ENABLE_MAEMO
diff --git a/glom/mode_data/db_adddel/db_adddel.h b/glom/mode_data/db_adddel/db_adddel.h
index 85cdc02..661d558 100644
--- a/glom/mode_data/db_adddel/db_adddel.h
+++ b/glom/mode_data/db_adddel/db_adddel.h
@@ -48,7 +48,7 @@ class DbTreeViewColumnGlom;
 /** For adding/deleting/selecting record rows.
  */
 class DbAddDel
- : public Gtk::VBox,
+ : public Gtk::Box,
    public Base_DB_Table_Data
 {
 public:
@@ -397,7 +397,7 @@ private:
 
   static void apply_formatting(Gtk::CellRenderer* renderer, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
 
-  typedef Gtk::VBox type_base;
+  typedef Gtk::Box type_base;
 
   //Member widgets:
   #ifdef GLOM_ENABLE_MAEMO
diff --git a/glom/mode_data/db_adddel/db_adddel_withbuttons.cc b/glom/mode_data/db_adddel/db_adddel_withbuttons.cc
index 5a47b59..399ecd0 100644
--- a/glom/mode_data/db_adddel/db_adddel_withbuttons.cc
+++ b/glom/mode_data/db_adddel/db_adddel_withbuttons.cc
@@ -143,7 +143,7 @@ void DbAddDel_WithButtons::setup_buttons()
 void DbAddDel_WithButtons::show_all_vfunc()
 {
   //Call the base class:
-  Gtk::VBox::show_all_vfunc();
+  Gtk::Box::show_all_vfunc();
 
   //Hide some stuff:
   setup_buttons();
diff --git a/glom/mode_data/flowtablewithfields.cc b/glom/mode_data/flowtablewithfields.cc
index 4fa95bb..ee919fc 100644
--- a/glom/mode_data/flowtablewithfields.cc
+++ b/glom/mode_data/flowtablewithfields.cc
@@ -577,10 +577,10 @@ void FlowTableWithFields::add_button(const sharedptr<LayoutItem_Button>& layouti
   bool expand = false;
   if(alignment != FieldFormatting::HORIZONTAL_ALIGNMENT_LEFT)
   {
-    //Put the button in a Gtk::HBox so we can have non-default alignment in
+    //Put the button in a Gtk::Box so we can have non-default alignment in
     //its space. Note that we will need a different technique if we ever
     //support center alignment.
-    Gtk::HBox* box_button = Gtk::manage(new Gtk::HBox());
+    Gtk::Box* box_button = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
     box_button->show();
     if(alignment == FieldFormatting::HORIZONTAL_ALIGNMENT_RIGHT)
       box_button->pack_end(*button, Gtk::PACK_SHRINK);
diff --git a/glom/mode_data/test_flowtablewithfields.cc b/glom/mode_data/test_flowtablewithfields.cc
index e7ee110..5f4f648 100644
--- a/glom/mode_data/test_flowtablewithfields.cc
+++ b/glom/mode_data/test_flowtablewithfields.cc
@@ -74,7 +74,7 @@ main(int argc, char* argv[])
   Gtk::Main mainInstance(argc, argv);
 
   Gtk::Window window;
-  //Gtk::VBox flowtable;
+  //Gtk::Box flowtable;
   Glom::FlowTableWithFields flowtable;
   flowtable.set_lines(2);
   flowtable.set_horizontal_spacing(6);
diff --git a/glom/mode_design/fields/dialog_fielddefinition.h b/glom/mode_design/fields/dialog_fielddefinition.h
index ec246b3..853cbe3 100644
--- a/glom/mode_design/fields/dialog_fielddefinition.h
+++ b/glom/mode_design/fields/dialog_fielddefinition.h
@@ -69,11 +69,11 @@ private:
   Combo_FieldType* m_pCombo_Type;
   Gtk::CheckButton* m_pCheck_Unique;
   Gtk::CheckButton* m_pCheck_NotNull;
-  Gtk::HBox* m_pBox_DefaultValueSimple;
+  Gtk::Box* m_pBox_DefaultValueSimple;
   Gtk::CheckButton* m_pCheck_PrimaryKey;
   Gtk::CheckButton* m_pCheck_AutoIncrement;
 
-  Gtk::VBox* m_pBox_ValueTab;
+  Gtk::Box* m_pBox_ValueTab;
 
   Gtk::RadioButton* m_pRadio_UserEntry;
   Gtk::Alignment* m_pAlignment_UserEntry;
@@ -91,7 +91,7 @@ private:
 
   DataWidget* m_pDataWidget_DefaultValueSimple;
 
-  Gtk::VBox* m_box_formatting_placeholder;
+  Gtk::Box* m_box_formatting_placeholder;
   Box_Formatting* m_box_formatting;
 
   sharedptr<Field> m_Field;
diff --git a/glom/mode_design/layout/layout_item_dialogs/box_formatting.cc b/glom/mode_design/layout/layout_item_dialogs/box_formatting.cc
index 29aa684..158be14 100644
--- a/glom/mode_design/layout/layout_item_dialogs/box_formatting.cc
+++ b/glom/mode_design/layout/layout_item_dialogs/box_formatting.cc
@@ -33,7 +33,7 @@ const char* Box_Formatting::glade_id("box_formatting");
 const bool Box_Formatting::glade_developer(true);
 
 Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
-: Gtk::VBox(cobject),
+: Gtk::Box(cobject),
   m_vbox_numeric_format(0),
   m_checkbox_format_use_thousands(0),
   m_checkbox_format_use_decimal_places(0),
diff --git a/glom/mode_design/layout/layout_item_dialogs/box_formatting.h b/glom/mode_design/layout/layout_item_dialogs/box_formatting.h
index 364d716..5e16027 100644
--- a/glom/mode_design/layout/layout_item_dialogs/box_formatting.h
+++ b/glom/mode_design/layout/layout_item_dialogs/box_formatting.h
@@ -36,7 +36,7 @@ namespace Glom
 class Dialog_FieldsList;
 
 class Box_Formatting
- : public Gtk::VBox,
+ : public Gtk::Box,
    public View_Composite_Glom
 {
 public:
@@ -76,29 +76,29 @@ private:
 
   void enforce_constraints();
 
-  Gtk::VBox* m_vbox_numeric_format;
+  Gtk::Box* m_vbox_numeric_format;
   Gtk::CheckButton* m_checkbox_format_use_thousands;
   Gtk::CheckButton* m_checkbox_format_use_decimal_places;
   Gtk::Entry* m_entry_format_decimal_places;
   ComboEntry_Currency* m_entry_currency_symbol;
   Gtk::CheckButton* m_checkbox_format_color_negatives;
 
-  Gtk::VBox* m_vbox_text_format;
+  Gtk::Box* m_vbox_text_format;
   Gtk::ComboBox* m_combo_format_text_horizontal_alignment;
   Gtk::CheckButton* m_checkbox_format_text_multiline;
   Gtk::Label* m_label_format_text_multiline_height;
   Gtk::SpinButton* m_spinbutton_format_text_multiline_height;
-  Gtk::HBox* m_hbox_font;
+  Gtk::Box* m_hbox_font;
   Gtk::CheckButton* m_checkbox_format_text_font;
   Gtk::FontButton* m_fontbutton;
-  Gtk::HBox* m_hbox_color_foreground;
+  Gtk::Box* m_hbox_color_foreground;
   Gtk::CheckButton* m_checkbox_format_text_color_foreground;
   Gtk::ColorButton* m_colorbutton_foreground;
-  Gtk::HBox* m_hbox_color_background;
+  Gtk::Box* m_hbox_color_background;
   Gtk::CheckButton* m_checkbox_format_text_color_background;
   Gtk::ColorButton* m_colorbutton_background;
 
-  Gtk::VBox* m_vbox_choices;
+  Gtk::Box* m_vbox_choices;
   Gtk::RadioButton* m_radiobutton_choices_custom;
   Gtk::RadioButton* m_radiobutton_choices_related;
   Gtk::CheckButton* m_checkbutton_choices_restricted;
diff --git a/glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h b/glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h
index 9e650f0..6be157f 100644
--- a/glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h
+++ b/glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h
@@ -65,7 +65,7 @@ private:
   Gtk::Entry* m_entry_title_custom;
 
 
-  Gtk::VBox* m_box_formatting_placeholder;
+  Gtk::Box* m_box_formatting_placeholder;
   Gtk::RadioButton* m_radiobutton_custom_formatting;
   Box_Formatting* m_box_formatting;
 
diff --git a/glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h b/glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h
index 870153a..ae1fcae 100644
--- a/glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h
+++ b/glom/mode_design/layout/layout_item_dialogs/dialog_imageobject.h
@@ -48,7 +48,7 @@ public:
 private:
   void on_button_choose();
 
-  Gtk::VBox* m_box_title;
+  Gtk::Box* m_box_title;
   Gtk::Entry* m_entry_title;
   ImageGlom* m_image;
   Gtk::Button* m_button_choose_image;
diff --git a/glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h b/glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h
index 6b426f7..5705a8b 100644
--- a/glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h
+++ b/glom/mode_design/layout/layout_item_dialogs/dialog_textobject.h
@@ -46,7 +46,7 @@ public:
   void get_textobject(sharedptr<LayoutItem_Text>& textobject) const;
 
 private:
-  Gtk::VBox* m_box_title;
+  Gtk::Box* m_box_title;
   Gtk::Entry* m_entry_title;
   Gtk::TextView* m_text_view;
 
diff --git a/glom/mode_design/print_layouts/dialog_text_formatting.h b/glom/mode_design/print_layouts/dialog_text_formatting.h
index 86220bb..bb408ce 100644
--- a/glom/mode_design/print_layouts/dialog_text_formatting.h
+++ b/glom/mode_design/print_layouts/dialog_text_formatting.h
@@ -44,7 +44,7 @@ public:
   virtual ~Dialog_TextFormatting();
 
   //Allow direct access, for convenience:
-  Gtk::VBox* m_box_formatting_placeholder;
+  Gtk::Box* m_box_formatting_placeholder;
   Box_Formatting* m_box_formatting;
 
 private:
diff --git a/glom/mode_design/print_layouts/window_print_layout_edit.h b/glom/mode_design/print_layouts/window_print_layout_edit.h
index 6ac0a45..0c34378 100644
--- a/glom/mode_design/print_layouts/window_print_layout_edit.h
+++ b/glom/mode_design/print_layouts/window_print_layout_edit.h
@@ -135,9 +135,9 @@ private:
   //Gtk::Label* m_label_table_title;
   Gtk::Button* m_button_close;
 
-  Gtk::VBox* m_box_menu;
-  Gtk::VBox* m_box_canvas;
-  Gtk::VBox* m_box;
+  Gtk::Box* m_box_menu;
+  Gtk::Box* m_box_canvas;
+  Gtk::Box* m_box;
   Gtk::ScrolledWindow m_scrolled_window;
   Canvas_PrintLayout m_canvas;
 
diff --git a/glom/mode_design/relationships_overview/dialog_relationships_overview.cc b/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
index 8fdc217..a2c0db7 100644
--- a/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
+++ b/glom/mode_design/relationships_overview/dialog_relationships_overview.cc
@@ -50,7 +50,7 @@ Dialog_RelationshipsOverview::Dialog_RelationshipsOverview(BaseObjectType* cobje
   m_refSettings = Gtk::PrintSettings::create();
 
   //Add a menu:
-  Gtk::VBox* vbox = 0;
+  Gtk::Box* vbox = 0;
   builder->get_widget("vbox_placeholder_menubar", vbox);
 
   m_refActionGroup = Gtk::ActionGroup::create();
diff --git a/glom/mode_find/box_data_list_find.cc b/glom/mode_find/box_data_list_find.cc
index f0c81ae..faa3218 100644
--- a/glom/mode_find/box_data_list_find.cc
+++ b/glom/mode_find/box_data_list_find.cc
@@ -26,7 +26,7 @@ namespace Glom
 {
 
 Box_Data_List_Find::Box_Data_List_Find()
-: m_HBox(false, Glom::Utils::DEFAULT_SPACING_SMALL)
+: m_HBox(Gtk::ORIENTATION_HORIZONTAL, Glom::Utils::DEFAULT_SPACING_SMALL)
 {
   //m_strHint = _("Enter the search criteria and click [Find]\n Glom will then change to Data mode to display the results.");
 
diff --git a/glom/mode_find/box_data_list_find.h b/glom/mode_find/box_data_list_find.h
index 34ab7fd..1e3dbda 100644
--- a/glom/mode_find/box_data_list_find.h
+++ b/glom/mode_find/box_data_list_find.h
@@ -42,7 +42,7 @@ private:
   virtual void create_layout();
 
   //Member widgets:
-  Gtk::HBox m_HBox;
+  Gtk::Box m_HBox;
 };
 
 } //namespace Glom
diff --git a/glom/utility_widgets/adddel/adddel.cc b/glom/utility_widgets/adddel/adddel.cc
index 5f942b3..7639214 100644
--- a/glom/utility_widgets/adddel/adddel.cc
+++ b/glom/utility_widgets/adddel/adddel.cc
@@ -75,7 +75,8 @@ AddDelColumnInfo& AddDelColumnInfo::operator=(const AddDelColumnInfo& src)
 }
 
 AddDel::AddDel()
-: m_col_key(0),
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_col_key(0),
   m_pMenuPopup(0),
   m_auto_add(true),
   m_allow_add(true),
@@ -86,7 +87,7 @@ AddDel::AddDel()
 
 
 AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::VBox(cobject),
+: Gtk::Box(cobject),
   m_col_key(0),
   m_pMenuPopup(0),
   m_auto_add(true),
diff --git a/glom/utility_widgets/adddel/adddel.h b/glom/utility_widgets/adddel/adddel.h
index cc7519a..2027721 100644
--- a/glom/utility_widgets/adddel/adddel.h
+++ b/glom/utility_widgets/adddel/adddel.h
@@ -63,7 +63,7 @@ public:
 
 //For adding/deleting/selecting multi-columned lists of items.
 //This was also an abstraction layer against the strangeness of GtkSheet, though it now uses Gtk::TreeView instead.
-class AddDel : public Gtk::VBox
+class AddDel : public Gtk::Box
 {
 public:
   friend class InnerIgnore; //declared below.
@@ -269,7 +269,7 @@ protected:
   template<class T_ModelColumnType>
   guint treeview_append_column(const Glib::ustring& title, const Gtk::TreeModelColumn<T_ModelColumnType>& column, const Glib::ustring& column_id);
 
-  typedef Gtk::VBox type_base;
+  typedef Gtk::Box type_base;
 
   //Member widgets:
   Gtk::ScrolledWindow m_ScrolledWindow;
diff --git a/glom/utility_widgets/eggspreadtablemm/test_spreadtablednd.cc b/glom/utility_widgets/eggspreadtablemm/test_spreadtablednd.cc
index f045f4e..ee6f37f 100644
--- a/glom/utility_widgets/eggspreadtablemm/test_spreadtablednd.cc
+++ b/glom/utility_widgets/eggspreadtablemm/test_spreadtablednd.cc
@@ -144,9 +144,9 @@ static Gtk::Window *
 create_window()
 {
   Gtk::Window* window = new Gtk::Window();
-  Gtk::HBox* hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  Gtk::Box* hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
-  Gtk::VBox* vbox = Gtk::manage(new Gtk::VBox(false, 6));
+  Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 6));
   vbox->show();
 
   window->set_border_width (8);
@@ -178,7 +178,7 @@ create_window()
   /* Add SpreadTable test control frame */
   Gtk::Expander* expander = Gtk::manage(new Gtk::Expander("SpreadTable controls"));
   expander->set_expanded();
-  Gtk::VBox* paper_cntl = Gtk::manage(new Gtk::VBox(false, 2));
+  Gtk::Box* paper_cntl = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 2));
   paper_cntl->show();;
   expander->show();
   expander->add(*paper_cntl);
@@ -198,7 +198,7 @@ create_window()
     sigc::ptr_fun(&on_combo_orientation_changed));
 
   /* Add horizontal/vertical spacing controls */
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   Gtk::Widget* label = Gtk::manage(new Gtk::Label("H Spacing"));
@@ -223,7 +223,7 @@ create_window()
 
   paper_cntl->pack_start(*hbox, false, false, 0);
 
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   label =  Gtk::manage(new Gtk::Label("V Spacing"));
@@ -268,7 +268,7 @@ create_window()
       togglebutton, child_accepts_drops));
 
   /* Add lines controls */
-  hbox = Gtk::manage(new Gtk::HBox(false, 2));
+  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 2));
   hbox->show();
 
   label = Gtk::manage(new Gtk::Label("Lines"));
@@ -293,7 +293,7 @@ create_window()
   /* Add test items control frame */
   expander = Gtk::manage(new Gtk::Expander("Test item controls"));
   expander->set_expanded();
-  Gtk::VBox* items_cntl = Gtk::manage(new Gtk::VBox(false, 2));
+  Gtk::Box* items_cntl = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, 2));
   items_cntl->show();
   expander->show();
   expander->add(*items_cntl);
diff --git a/glom/utility_widgets/filechooserdialog_saveextras.cc b/glom/utility_widgets/filechooserdialog_saveextras.cc
index 9b7d396..dd00461 100644
--- a/glom/utility_widgets/filechooserdialog_saveextras.cc
+++ b/glom/utility_widgets/filechooserdialog_saveextras.cc
@@ -29,25 +29,29 @@ namespace Glom
 {
 
 FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(const Glib::ustring& title, Gtk::FileChooserAction action, const Glib::ustring& backend)
-: Gtk::FileChooserDialog(title, action, backend)
+: Gtk::FileChooserDialog(title, action, backend),
+  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
 {
   create_child_widgets();
 }
 
 FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(Gtk::Window& parent, const Glib::ustring& title, Gtk::FileChooserAction action, const Glib::ustring& backend)
-: Gtk::FileChooserDialog(parent, title, action, backend)
+: Gtk::FileChooserDialog(parent, title, action, backend),
+  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
 {
   create_child_widgets();
 }
 
 FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(const Glib::ustring& title, Gtk::FileChooserAction action)
-: Gtk::FileChooserDialog(title, action)
+: Gtk::FileChooserDialog(title, action),
+  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
 {
   create_child_widgets();
 }
 
 FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(Gtk::Window& parent, const Glib::ustring& title, Gtk::FileChooserAction action)
-: Gtk::FileChooserDialog(parent, title, action)
+: Gtk::FileChooserDialog(parent, title, action),
+  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
 {
   create_child_widgets();
 }
@@ -86,7 +90,7 @@ void FileChooserDialog_SaveExtras::create_child_widgets()
   frame->add(*alignment);
   frame->show();
 
-  Gtk::VBox* vbox = Gtk::manage(new Gtk::VBox(false, Utils::DEFAULT_SPACING_SMALL));
+  Gtk::Box* vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, Utils::DEFAULT_SPACING_SMALL));
   alignment->add(*vbox);
   vbox->show();
 
@@ -97,7 +101,7 @@ void FileChooserDialog_SaveExtras::create_child_widgets()
   label_newdb->set_alignment(0.0f, 0.5f);
   label_newdb->show();
 
-  Gtk::HBox* box_label = Gtk::manage(new Gtk::HBox(false, Utils::DEFAULT_SPACING_LARGE));
+  Gtk::Box* box_label = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_LARGE));
   Gtk::Label* label_title = Gtk::manage(new Gtk::Label(_("_Title:"), true));
   box_label->pack_start(*label_title, Gtk::PACK_SHRINK);
   label_title->show();
diff --git a/glom/utility_widgets/filechooserdialog_saveextras.h b/glom/utility_widgets/filechooserdialog_saveextras.h
index a507d69..379344c 100644
--- a/glom/utility_widgets/filechooserdialog_saveextras.h
+++ b/glom/utility_widgets/filechooserdialog_saveextras.h
@@ -61,7 +61,7 @@ public:
 private:
   void create_child_widgets();
 
-  Gtk::VBox m_extra_widget;
+  Gtk::Box m_extra_widget;
   Gtk::Label m_label_extra_message;
 
   /* New database details: */
diff --git a/glom/utility_widgets/flowtable.h b/glom/utility_widgets/flowtable.h
index b2b290f..c143980 100644
--- a/glom/utility_widgets/flowtable.h
+++ b/glom/utility_widgets/flowtable.h
@@ -65,16 +65,16 @@ protected:
 
 private:
 
-  const Gtk::HBox* get_parent_hbox(const Gtk::Widget* first) const;
-  void delete_and_forget_hbox(Gtk::HBox* hbox);
+  const Gtk::Box* get_parent_hbox(const Gtk::Widget* first) const;
+  void delete_and_forget_hbox(Gtk::Box* hbox);
 
   bool m_design_mode;
 
   //For drawing:
   Glib::RefPtr<Gdk::Window> m_refGdkWindow;
 
-  //We remember the HBoxes so we can delete them when the are no longer used.
-  typedef std::list<Gtk::HBox*> type_list_hboxes;
+  //We remember the Boxes so we can delete them when the are no longer used.
+  typedef std::list<Gtk::Box*> type_list_hboxes;
   type_list_hboxes m_list_hboxes;
 
   type_const_list_widgets m_list_first_widgets;
diff --git a/glom/utility_widgets/placeholder.cc b/glom/utility_widgets/placeholder.cc
index f7e1b99..9c4e756 100644
--- a/glom/utility_widgets/placeholder.cc
+++ b/glom/utility_widgets/placeholder.cc
@@ -24,12 +24,13 @@ namespace Glom
 {
 
 PlaceHolder::PlaceHolder()
-: m_pChild(0)
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_pChild(0)
 {
 }
 
 PlaceHolder::PlaceHolder(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /*builder*/)
-: Gtk::VBox(cobject),
+: Gtk::Box(cobject),
   m_pChild(0)
 {
 }
@@ -49,7 +50,7 @@ void PlaceHolder::remove()
 {
   if(m_pChild)
   {
-    Gtk::VBox::remove(*m_pChild);
+    Gtk::Box::remove(*m_pChild);
     m_pChild = 0;
   }
 }
diff --git a/glom/utility_widgets/placeholder.h b/glom/utility_widgets/placeholder.h
index bbe5b3c..6406abe 100644
--- a/glom/utility_widgets/placeholder.h
+++ b/glom/utility_widgets/placeholder.h
@@ -28,7 +28,7 @@ namespace Glom
 {
 
 //TODO: Remove this, using the vbox directly?
-class PlaceHolder : public Gtk::VBox
+class PlaceHolder : public Gtk::Box
 {
 public:
   PlaceHolder();
diff --git a/glom/utility_widgets/test_flowtable.cc b/glom/utility_widgets/test_flowtable.cc
index d8b37d8..87036f1 100644
--- a/glom/utility_widgets/test_flowtable.cc
+++ b/glom/utility_widgets/test_flowtable.cc
@@ -99,7 +99,7 @@ main(int argc, char* argv[])
   Gtk::Main mainInstance(argc, argv);
 
   Gtk::Window window;
-  //Gtk::VBox flowtable;
+  //Gtk::Box flowtable;
   Glom::FlowTable flowtable;
   flowtable.set_lines(2);
   flowtable.set_horizontal_spacing(6);
diff --git a/glom/utility_widgets/test_flowtable_dnd.cc b/glom/utility_widgets/test_flowtable_dnd.cc
index 2c9114c..6c3a3ec 100644
--- a/glom/utility_widgets/test_flowtable_dnd.cc
+++ b/glom/utility_widgets/test_flowtable_dnd.cc
@@ -42,7 +42,7 @@ main(int argc, char* argv[])
   Gtk::Main mainInstance(argc, argv);
 
   Gtk::Window window;
-  //Gtk::VBox flowtable;
+  //Gtk::Box flowtable;
   Glom::FlowTableDnd flowtable;
   flowtable.set_columns_count(3);
   flowtable.set_column_padding(100);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/glom/utility_widgets/flowtable.cc b/glom/utility_widgets/flowtable.cc
index 6ea612f..a44ee80 100644
--- a/glom/utility_widgets/flowtable.cc
+++ b/glom/utility_widgets/flowtable.cc
@@ -38,24 +38,24 @@ FlowTable::~FlowTable()
   while(!m_list_hboxes.empty())
   {
     type_list_hboxes::iterator iter = m_list_hboxes.begin();
-    Gtk::HBox* hbox = *iter;
+    Gtk::Box* hbox = *iter;
     delete_and_forget_hbox(hbox);
   }
 }
 
-const Gtk::HBox* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
+const Gtk::Box* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
 {
   const type_const_list_widgets::const_iterator iter_find = 
     std::find(m_list_first_widgets.begin(), m_list_first_widgets.end(), first);
   if(iter_find == m_list_first_widgets.end())
   {
     std::cerr << G_STRFUNC << ": first was not a first widget. first=" << first << std::endl;
-    return 0; //It has no HBox parent because it is not even a first widget.
+    return 0; //It has no Box parent because it is not even a first widget.
   }
   
   for(type_list_hboxes::const_iterator iter = m_list_hboxes.begin(); iter != m_list_hboxes.end(); ++iter)
   {
-    const Gtk::HBox* hbox = *iter;
+    const Gtk::Box* hbox = *iter;
     if(!hbox)
       continue;
 
@@ -73,10 +73,10 @@ const Gtk::HBox* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
   return 0;
 }
 
-void FlowTable::delete_and_forget_hbox(Gtk::HBox* hbox)
+void FlowTable::delete_and_forget_hbox(Gtk::Box* hbox)
 {
   //Remove its children because the API hides the fact that they are inside the HBox.
   //Otherwise they could even be deleted by the HBox.
   typedef std::vector<Widget*> type_children;
   type_children children = hbox->get_children();
   while(!children.empty())
@@ -136,7 +136,7 @@ void FlowTable::insert(Gtk::Widget* first, Gtk::Widget* second, int index, bool
 {
   if(first && second)
   {
-    Gtk::HBox* hbox = new Gtk::HBox(false, get_horizontal_spacing());
+    Gtk::Box* hbox = new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, get_horizontal_spacing());
     m_list_hboxes.push_back(hbox); //So we can delete it whenever necessary.
 
     hbox->pack_start(*first, Gtk::PACK_SHRINK);
@@ -190,8 +190,8 @@ void FlowTable::remove(Gtk::Widget& first)
 {
   //std::cout << G_STRFUNC << ": debug: remove() first=" << &first << std::endl;
   
-  //Handle widgets that were added to an HBox:
-  Gtk::HBox* parent = const_cast<Gtk::HBox*>(get_parent_hbox(&first));
+  //Handle widgets that were added to an Box:
+  Gtk::Box* parent = const_cast<Gtk::Box*>(get_parent_hbox(&first));
   if(parent)
   {
     //std::cout << "  debug: hbox=" << parent << std::endl;
@@ -228,8 +228,8 @@ bool FlowTable::get_column_for_first_widget(const Gtk::Widget& first, guint& col
     
   child = &first;
   
-  //Check if it was added to an HBox:
-  const Gtk::HBox* hbox = get_parent_hbox(child);
+  //Check if it was added to an Box:
+  const Gtk::Box* hbox = get_parent_hbox(child);
   if(hbox)
     child = hbox;
     
@@ -73,10 +73,10 @@ const Gtk::HBox* FlowTable::get_parent_hbox(const Gtk::Widget* first) const
 {
-  //Remove its children because the API hides the fact that they are inside the HBox.
-  //Otherwise they could even be deleted by the HBox.
+  //Remove its children because the API hides the fact that they are inside the Box.
+  //Otherwise they could even be deleted by the Box.
   typedef std::vector<Widget*> type_children;
   type_children children = hbox->get_children();